clear all
set more off

************* Generating Figure 12 *************************

global datadir = "C:\Users\17786\OneDrive\Desktop\Data" // Specify directory where main folder is
global figures = "${datadir}\Figures" // Specify directory where figures will be saved
global adobase = "${datadir}\ado" // Directory where additional ado programs are stored needed for replication

// Replacing the PERSONAL, PLUS and SITE directories where additional ado programs are located
sysdir set PERSONAL ${adobase}
sysdir set PLUS ${adobase}
sysdir set SITE ${adobase}

cd ${datadir}

import excel "${datadir}\endogenous_occupations_occ_risk.xlsx", sheet("Sheet1") firstrow clear

egen ID_str = rank(Relativehomewage)
labmask ID_str, values(NOC_short)

sort ID_str

lab var baseline "Baseline"
lab var tax5 "Tax 5%, duration 36 weeks"
lab var tax12 "Tax 12%, duration 12 weeks"

gen model_exit = ID_str if baseline>0
egen re_id = rank(model_exit), field

gen id_1 = 5*(re_id-1) + 1
gen id_2 = 5*(re_id-1) + 2
gen id_3 = 5*(re_id-1) + 3

labmask id_1, values(NOC_short) 
labmask id_2, values(NOC_short)
labmask id_3, values(NOC_short)


splitvallabels id_1, length(46)
twoway (bar baseline id_1, fcolor(gs6) lcolor(black) horizontal ytitle(" ")) || (bar tax5 id_2, horizontal ytitle(" ") fcolor(white) lcolor(black)) ///
|| (bar tax12 id_3, fcolor(gs0) lcolor(black) horizontal ytitle(" ")), xtitle("Weeks") ///
ylabel(`r(relabel)', labsize(*.6) angle(0) nogrid) graphregion(color(white)) bgcolor(white) ///
legend( position(4) ring(0) rows(3) cols(1) size(small) region(lcolor(white))) ysc(reverse) ysc(noline)
graph export "${figures}\Figure_12.pdf", replace
